#[non_exhaustive]pub struct DeltaQuery<T: DeltaSyncCacheable> {
pub since: Option<T::Watermark>,
pub recover_ids: HashSet<T::Id>,
}Expand description
Query passed to DeltaPunnuFetcher::fetch_delta.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.since: Option<T::Watermark>The current subscription watermark. None means a full query.
When this is Some, fetchers must query with an inclusive
>= boundary and let Sassi deduplicate rows by identity.
recover_ids: HashSet<T::Id>IDs that must be recovered regardless of watermark.
Eviction recovery uses this to ask the fetcher for IDs that this subscription previously observed but L1 later evicted.